pub enum StatusCode {
Show 74 variants
Trying,
Ringing,
CallIsBeingForwarded,
Queued,
SessionProgress,
EarlyDialogTerminated,
OK,
Accepted,
NoNotification,
MultipleChoices,
MovedPermanently,
MovedTemporarily,
UseProxy,
AlternativeService,
BadRequest,
Unauthorized,
PaymentRequired,
Forbidden,
NotFound,
MethodNotAllowed,
NotAcceptable,
ProxyAuthenticationRequired,
RequestTimeout,
Conflict,
Gone,
LengthRequired,
ConditionalRequestFailed,
RequestEntityTooLarge,
RequestUriTooLong,
UnsupportedMediaType,
UnsupportedUriScheme,
UnknownResourcePriority,
BadExtension,
ExtensionRequired,
SessionIntervalTooSmall,
IntervalTooBrief,
BadLocationInformation,
UseIdentityHeader,
ProvideReferrerIdentity,
AnonymityDisallowed,
BadIdentityInfo,
UnsupportedCertificate,
InvalidIdentityHeader,
FirstHopLacksOutboundSupport,
MaxBreadthExceeded,
BadInfoPackage,
ConsentNeeded,
TemporarilyUnavailable,
CallTransactionDoesNotExist,
LoopDetected,
TooManyHops,
AddressIncomplete,
Ambiguous,
BusyHere,
RequestTerminated,
NotAcceptableHere,
BadEvent,
RequestPending,
Undecipherable,
SecurityAgreementRequired,
ServerInternalError,
NotImplemented,
BadGateway,
ServiceUnavailable,
ServerTimeOut,
VersionNotSupported,
MessageTooLarge,
PreconditionFailure,
BusyEverywhere,
Decline,
DoesNotExistAnywhere,
NotAcceptableGlobal,
Unwanted,
Other(u16, String),
}Expand description
The SIP Response status code (or response code as SIP main
RFC refers to them). This is not a Copy type because in case of an unknown (= not
defined in any SIP RFC) status code, the reason is also provided inside the Other
tuple variant.
Variants
Trying
Ringing
CallIsBeingForwarded
Queued
SessionProgress
EarlyDialogTerminated
OK
Accepted
NoNotification
MultipleChoices
MovedPermanently
MovedTemporarily
UseProxy
AlternativeService
BadRequest
PaymentRequired
Forbidden
NotFound
MethodNotAllowed
NotAcceptable
ProxyAuthenticationRequired
RequestTimeout
Conflict
Gone
LengthRequired
ConditionalRequestFailed
RequestEntityTooLarge
RequestUriTooLong
UnsupportedMediaType
UnsupportedUriScheme
UnknownResourcePriority
BadExtension
ExtensionRequired
SessionIntervalTooSmall
IntervalTooBrief
BadLocationInformation
UseIdentityHeader
ProvideReferrerIdentity
AnonymityDisallowed
BadIdentityInfo
UnsupportedCertificate
InvalidIdentityHeader
FirstHopLacksOutboundSupport
MaxBreadthExceeded
BadInfoPackage
ConsentNeeded
CallTransactionDoesNotExist
LoopDetected
TooManyHops
AddressIncomplete
Ambiguous
BusyHere
RequestTerminated
NotAcceptableHere
BadEvent
RequestPending
Undecipherable
SecurityAgreementRequired
ServerInternalError
NotImplemented
BadGateway
ServerTimeOut
VersionNotSupported
MessageTooLarge
PreconditionFailure
BusyEverywhere
Decline
DoesNotExistAnywhere
NotAcceptableGlobal
Unwanted
Other(u16, String)
Implementations
Sourceimpl StatusCode
impl StatusCode
pub fn kind(&self) -> StatusCodeKind