Header

Enum Header 

pub enum Header {
Show 47 variants Accept(Accept), AcceptEncoding(AcceptEncoding), AcceptLanguage(AcceptLanguage), AlertInfo(AlertInfo), Allow(Allow), AuthenticationInfo(AuthenticationInfo), Authorization(Authorization), CSeq(CSeq), CallId(CallId), CallInfo(CallInfo), Contact(Contact), ContentDisposition(ContentDisposition), ContentEncoding(ContentEncoding), ContentLanguage(ContentLanguage), ContentLength(ContentLength), ContentType(ContentType), Date(Date), ErrorInfo(ErrorInfo), Event(Event), Expires(Expires), From(From), InReplyTo(InReplyTo), MaxForwards(MaxForwards), MimeVersion(MimeVersion), MinExpires(MinExpires), Organization(Organization), Other(String, String), Priority(Priority), ProxyAuthenticate(ProxyAuthenticate), ProxyAuthorization(ProxyAuthorization), ProxyRequire(ProxyRequire), RecordRoute(RecordRoute), ReplyTo(ReplyTo), Require(Require), RetryAfter(RetryAfter), Route(Route), Server(Server), Subject(Subject), SubscriptionState(SubscriptionState), Supported(Supported), Timestamp(Timestamp), To(To), Unsupported(Unsupported), UserAgent(UserAgent), Via(Via), Warning(Warning), WwwAuthenticate(WwwAuthenticate),
}
Big enum holding in each variant every possible header defined in SIP. All variants hold an untyped header which is basically a NewType around String.

In case a header is not defined in Rsip, parsing will store it in the Other variant, which is a tuple of Strings. For instance, constructing the X-Fs-Sending-Message header (related to SMS in SIP), you can do:

let x_fs_sending_message = ftth_rsip::Header::Other("X-FS-Sending-Message".into(), "f9c4adc8-9c2a-47d5-a7f1-63d20784685e".into());

Variants



Accept(Accept)



AcceptEncoding(AcceptEncoding)



AcceptLanguage(AcceptLanguage)



AlertInfo(AlertInfo)



Allow(Allow)



AuthenticationInfo(AuthenticationInfo)



Authorization(Authorization)



CSeq(CSeq)



CallId(CallId)



CallInfo(CallInfo)



Contact(Contact)



ContentDisposition(ContentDisposition)



ContentEncoding(ContentEncoding)



ContentLanguage(ContentLanguage)



ContentLength(ContentLength)



ContentType(ContentType)



Date(Date)



ErrorInfo(ErrorInfo)



Event(Event)



Expires(Expires)



From(From)



InReplyTo(InReplyTo)



MaxForwards(MaxForwards)



MimeVersion(MimeVersion)



MinExpires(MinExpires)



Organization(Organization)



Other(String, String)



Priority(Priority)



ProxyAuthenticate(ProxyAuthenticate)



ProxyAuthorization(ProxyAuthorization)



ProxyRequire(ProxyRequire)



RecordRoute(RecordRoute)



ReplyTo(ReplyTo)



Require(Require)



RetryAfter(RetryAfter)



Route(Route)



Server(Server)



Subject(Subject)



SubscriptionState(SubscriptionState)



Supported(Supported)



Timestamp(Timestamp)



To(To)



Unsupported(Unsupported)



UserAgent(UserAgent)



Via(Via)



Warning(Warning)



WwwAuthenticate(WwwAuthenticate)