pub struct Request {
pub method: Method,
pub uri: Uri,
pub version: Version,
pub headers: Headers,
pub body: Vec<u8>,
}Expand description
Request reprsents a SIP request message, which contains a Method,
a Uri, a Version, Headers and a
body, represented as a Vec<u8>, thus not checked for UTF-8 compliance.
A Request can easily be transformed to a SipMessage.
Also it can be converted to a String, &str, or Bytes, all using the underlying Debug
trait.
In order to access specific headers, you should take a look on the HeadersExt trait that is automatically implemented for any type that has implemented the HasHeaders trait, which Request implements it.
Fields
method: Methoduri: Uriversion: Versionheaders: Headersbody: Vec<u8>Implementations